/* Copyright (C) 2022 Alif Semiconductor - All Rights Reserved.
 * Use, distribution and modification of this code is permitted under the
 * terms stated in the Alif Semiconductor Software License Agreement
 *
 * You should have received a copy of the Alif Semiconductor Software
 * License Agreement with this file. If not, please write to:
 * contact@alifsemi.com, or visit: https://alifsemi.com/license
 *
 */

/******************************************************************************
 * @file     board_AppKit_Alpha2.c
 * @brief    BOARD API implementation for Alif AI/ML Application Kit (Rev. B)
 ******************************************************************************/

#include "board.h"

#if defined(BOARD_IS_ALIF_APPKIT_ALPHA2_VARIANT)
#include "app_map.h"
#include "global_map.h"
#include "Driver_GPIO.h"
#include "Driver_PINMUX_AND_PINPAD.h"
#include "UTIMER_ll_drv.h"

extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_BUTTON1_GPIO_PORT);
extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_BUTTON2_GPIO_PORT);
extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_LED1_GPIO_PORT);
extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_LED2_GPIO_PORT);

void BOARD_Pinmux_Init()
{
	extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_LCD_RESET_GPIO_PORT);
	extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_LCD_BACKLIGHT_GPIO_PORT);
	extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_TOUCH_RESET_GPIO_PORT);
	extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_TOUCH_INT_GPIO_PORT);
	extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_CAMERA_RESET_GPIO_PORT);
	extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_CAMERA_POWER_GPIO_PORT);

	ARM_DRIVER_GPIO *BOARD_BUTTON1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON1_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_BUTTON2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON2_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_LED1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LED1_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_LED2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LED2_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_LCD_RESET_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LCD_RESET_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_LCD_BACKLIGHT_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LCD_BACKLIGHT_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_TOUCH_RESET_GPIOdrv = &ARM_Driver_GPIO_(BOARD_TOUCH_RESET_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_TOUCH_INT_GPIOdrv = &ARM_Driver_GPIO_(BOARD_TOUCH_INT_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_CAMERA_RESET_GPIOdrv = &ARM_Driver_GPIO_(BOARD_CAMERA_RESET_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_CAMERA_POWER_GPIOdrv = &ARM_Driver_GPIO_(BOARD_CAMERA_POWER_GPIO_PORT);

	uint32_t config_i3c =
			PAD_FUNCTION_READ_ENABLE |
			PAD_FUNCTION_DRIVER_DISABLE_STATE_WITH_PULL_UP |
			PAD_FUNCTION_DRIVER_OPEN_DRAIN;

	/* GPIO interfaces - initial GPIO state is lowest power */

	HW_REG32(PINMUX_BASE, 0x10) = 0;
	HW_REG32(PINMUX_BASE, 0x14) = 0;
	HW_REG32(PINMUX_BASE, 0x18) = 0;
	HW_REG32(PINMUX_BASE, 0x1C) = 0x11110011;	/* PINMUX for JTAG and SE-UART */
	HW_REG32(PINMUX_BASE, 0x20) = 0;
	HW_REG32(PINMUX_BASE, 0x24) = 0;
	HW_REG32(PINMUX_BASE, 0x28) = 0;
	HW_REG32(PINMUX_BASE, 0x2C) = 0;
	HW_REG32(PINMUX_BASE, 0x30) = 0;
	HW_REG32(PINMUX_BASE, 0x34) = 0;
	HW_REG32(PINMUX_BASE, 0x38) = 0;

	BOARD_BUTTON1_GPIOdrv->SetDirection(BOARD_BUTTON1_PIN_NO, GPIO_PIN_DIRECTION_INPUT);
	PINMUX_Config(BOARD_BUTTON1_GPIO_PORT-1, BOARD_BUTTON1_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_BUTTON2_GPIOdrv->SetDirection(BOARD_BUTTON2_PIN_NO, GPIO_PIN_DIRECTION_INPUT);
	PINMUX_Config(BOARD_BUTTON2_GPIO_PORT-1, BOARD_BUTTON2_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_LED1_GPIOdrv->SetValue(BOARD_LED1_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_LED1_GPIOdrv->SetDirection(BOARD_LED1_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_LED1_GPIO_PORT-1, BOARD_LED1_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_LED2_GPIOdrv->SetValue(BOARD_LED2_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_LED2_GPIOdrv->SetDirection(BOARD_LED2_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_LED2_GPIO_PORT-1, BOARD_LED2_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_LCD_RESET_GPIOdrv->SetValue(BOARD_LCD_RESET_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_LCD_RESET_GPIOdrv->SetDirection(BOARD_LCD_RESET_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_LCD_RESET_GPIO_PORT-1, BOARD_LCD_RESET_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_LCD_BACKLIGHT_GPIOdrv->SetValue(BOARD_LCD_BACKLIGHT_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_LCD_BACKLIGHT_GPIOdrv->SetDirection(BOARD_LCD_BACKLIGHT_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_LCD_BACKLIGHT_GPIO_PORT-1, BOARD_LCD_BACKLIGHT_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_TOUCH_RESET_GPIOdrv->SetValue(BOARD_TOUCH_RESET_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_TOUCH_RESET_GPIOdrv->SetDirection(BOARD_TOUCH_RESET_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_TOUCH_RESET_GPIO_PORT-1, BOARD_TOUCH_RESET_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_TOUCH_INT_GPIOdrv->SetValue(BOARD_TOUCH_INT_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_TOUCH_INT_GPIOdrv->SetDirection(BOARD_TOUCH_INT_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_TOUCH_INT_GPIO_PORT-1, BOARD_TOUCH_INT_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_CAMERA_RESET_GPIOdrv->SetValue(BOARD_CAMERA_RESET_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_CAMERA_RESET_GPIOdrv->SetDirection(BOARD_CAMERA_RESET_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_CAMERA_RESET_GPIO_PORT-1, BOARD_CAMERA_RESET_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_CAMERA_POWER_GPIOdrv->SetValue(BOARD_CAMERA_POWER_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_CAMERA_POWER_GPIOdrv->SetDirection(BOARD_CAMERA_POWER_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_CAMERA_POWER_GPIO_PORT-1, BOARD_CAMERA_POWER_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	/* I3C interface */
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_6, PINMUX_ALTERNATE_FUNCTION_3);    // P2_6: SDA (mux mode 3)
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_6, config_i3c);
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_7, PINMUX_ALTERNATE_FUNCTION_3);    // P2_7: SCL (mux mode 3)
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_7, config_i3c);

	/* OSPI1 interface */
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_8, PINMUX_ALTERNATE_FUNCTION_4);  // D0
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_9, PINMUX_ALTERNATE_FUNCTION_4);  // D1
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_10, PINMUX_ALTERNATE_FUNCTION_4); // D2
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_11, PINMUX_ALTERNATE_FUNCTION_4); // D3
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_12, PINMUX_ALTERNATE_FUNCTION_4); // D4
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_13, PINMUX_ALTERNATE_FUNCTION_4); // D5
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_14, PINMUX_ALTERNATE_FUNCTION_3); // D6
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_15, PINMUX_ALTERNATE_FUNCTION_4); // D7
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_16, PINMUX_ALTERNATE_FUNCTION_4); // RXDS
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_17, PINMUX_ALTERNATE_FUNCTION_3); // CS
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_19, PINMUX_ALTERNATE_FUNCTION_4); // SCLK
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_5, PINMUX_ALTERNATE_FUNCTION_0);  // RESET
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_8, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_9, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_10, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_11, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_12, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_13, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_14, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_15, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_16, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_17, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_19, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_3, PIN_NUMBER_5, PAD_FUNCTION_READ_ENABLE);

	/* CAMERA clock output */
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_15, PINMUX_ALTERNATE_FUNCTION_7);
}

void BOARD_Clock_Init()
{
	/* Configure any SoC clock muxes and dividers
	 * if not already covered in driver code
	 */
}

void BOARD_Power_Init()
{
	/* Configure any board level power supplies */
#if 0
#define LCD_BACKLIGHT_UT_CHAN 11

	TIMER_RegInfo * reg = (TIMER_RegInfo *) UTIMER_BASE;
	_TIMER_Channel_RegInfo * chan = reg->TIMER_Channel_RegInfo + LCD_BACKLIGHT_UT_CHAN;
	reg->TIMER_Glb_RegInfo.glb_driver_oen &= ~(3 << (LCD_BACKLIGHT_UT_CHAN * 2));
	chan->cntr_start_src = CNTR_SRC_PGM_EN;
	chan->chan_interrupt_mask = 0;
	chan->cntr_ptr = 400000 - 1;
	chan->cntr_ctrl = 1;
	chan->cntr = 0;
	chan->compare_b = 350000 - 1;
	chan->compare_ctrl_b = 0x090f;
	chan->buf_op_ctrl = 0;
	reg->TIMER_Glb_RegInfo.glb_cntr_start |= (1 << LCD_BACKLIGHT_UT_CHAN);

	PINMUX_Config(BOARD_LCD_BACKLIGHT_GPIO_PORT-1, BOARD_LCD_BACKLIGHT_PIN_NO, PINMUX_ALTERNATE_FUNCTION_6);
#endif
}

void BOARD_BUTTON1_Init(BOARD_Callback_t user_cb)
{
	ARM_DRIVER_GPIO *BOARD_BUTTON1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON1_GPIO_PORT);
	BOARD_BUTTON1_GPIOdrv->Initialize(BOARD_BUTTON1_PIN_NO, user_cb);
}

void BOARD_BUTTON2_Init(BOARD_Callback_t user_cb)
{
	ARM_DRIVER_GPIO *BOARD_BUTTON2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON2_GPIO_PORT);
	BOARD_BUTTON2_GPIOdrv->Initialize(BOARD_BUTTON2_PIN_NO, user_cb);
}

void BOARD_BUTTON1_Control(BOARD_BUTTON_CONTROL control)
{
	uint32_t arg = ARM_GPIO_IRQ_POLARITY_LOW | ARM_GPIO_IRQ_SENSITIVE_EDGE;

	ARM_DRIVER_GPIO *BOARD_BUTTON1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON1_GPIO_PORT);
	BOARD_BUTTON1_GPIOdrv->Control(BOARD_BUTTON1_PIN_NO, (GPIO_OPERATION) control, &arg);
}

void BOARD_BUTTON2_Control(BOARD_BUTTON_CONTROL control)
{
	uint32_t arg = ARM_GPIO_IRQ_POLARITY_LOW | ARM_GPIO_IRQ_SENSITIVE_EDGE;

	ARM_DRIVER_GPIO *BOARD_BUTTON2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON2_GPIO_PORT);
	BOARD_BUTTON2_GPIOdrv->Control(BOARD_BUTTON2_PIN_NO, (GPIO_OPERATION) control, &arg);
}

void BOARD_BUTTON1_GetState(BOARD_BUTTON_STATE *state)
{
	ARM_DRIVER_GPIO *BOARD_BUTTON1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON1_GPIO_PORT);
	BOARD_BUTTON1_GPIOdrv->GetValue(BOARD_BUTTON1_PIN_NO, (uint32_t*)state);
}
void BOARD_BUTTON2_GetState(BOARD_BUTTON_STATE *state)
{
	ARM_DRIVER_GPIO *BOARD_BUTTON2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON2_GPIO_PORT);
	BOARD_BUTTON2_GPIOdrv->GetValue(BOARD_BUTTON2_PIN_NO, (uint32_t*)state);
}

void BOARD_LED1_Control(BOARD_LED_STATE state)
{
	ARM_DRIVER_GPIO *BOARD_LED1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LED1_GPIO_PORT);
	BOARD_LED1_GPIOdrv->SetValue(BOARD_LED1_PIN_NO, (GPIO_PIN_OUTPUT_STATE) state);
}

void BOARD_LED2_Control(BOARD_LED_STATE state)
{
	ARM_DRIVER_GPIO *BOARD_LED2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LED2_GPIO_PORT);
	BOARD_LED2_GPIOdrv->SetValue(BOARD_LED2_PIN_NO, (GPIO_PIN_OUTPUT_STATE) state);
}
#endif
