/* Copyright (C) 2022 Alif Semiconductor - All Rights Reserved.
 * Use, distribution and modification of this code is permitted under the
 * terms stated in the Alif Semiconductor Software License Agreement
 *
 * You should have received a copy of the Alif Semiconductor Software
 * License Agreement with this file. If not, please write to:
 * contact@alifsemi.com, or visit: https://alifsemi.com/license
 *
 */

/******************************************************************************
 * @file     board_DevKit.c
 * @brief    BOARD API implementation for Alif Development Kit (Rev. A and B)
 ******************************************************************************/

#include "board.h"

#if defined(BOARD_IS_ALIF_DEVKIT_VARIANT)
#include "app_map.h"
#include "global_map.h"
#include "Driver_GPIO.h"
#include "Driver_PINMUX_AND_PINPAD.h"

extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_BUTTON1_GPIO_PORT);
extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_BUTTON2_GPIO_PORT);
extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_LED1_GPIO_PORT);
extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_LED2_GPIO_PORT);

void BOARD_Pinmux_Init()
{
	extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_LCD_RESET_GPIO_PORT);
	extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_LCD_BACKLIGHT_GPIO_PORT);
	extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_TOUCH_RESET_GPIO_PORT);
	extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_TOUCH_INT_GPIO_PORT);
	extern ARM_DRIVER_GPIO ARM_Driver_GPIO_(BOARD_CAMERA_RESET_GPIO_PORT);

	ARM_DRIVER_GPIO *BOARD_BUTTON1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON1_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_BUTTON2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON2_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_LED1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LED1_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_LED2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LED2_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_LCD_RESET_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LCD_RESET_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_LCD_BACKLIGHT_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LCD_BACKLIGHT_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_TOUCH_RESET_GPIOdrv = &ARM_Driver_GPIO_(BOARD_TOUCH_RESET_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_TOUCH_INT_GPIOdrv = &ARM_Driver_GPIO_(BOARD_TOUCH_INT_GPIO_PORT);
	ARM_DRIVER_GPIO *BOARD_CAMERA_RESET_GPIOdrv = &ARM_Driver_GPIO_(BOARD_CAMERA_RESET_GPIO_PORT);

	uint8_t config_i3c =
			PAD_FUNCTION_READ_ENABLE |
			PAD_FUNCTION_DRIVER_DISABLE_STATE_WITH_PULL_UP |
			PAD_FUNCTION_DRIVER_OPEN_DRAIN;

	/* GPIO interfaces - initial GPIO state is lowest power */

#if _APP_ADDRESS >= OSPI0_MEM_BASE
	HW_REG32(PINMUX_BASE, 0x10) = 0;
	HW_REG32(PINMUX_BASE, 0x14) = 0;
	HW_REG32(PINMUX_BASE, 0x18) = 0x34433333;	/* PINMUX for OSPI0 */
	HW_REG32(PINMUX_BASE, 0x1C) = 0x11110330;	/* PINMUX for JTAG and OSPI0 */
	HW_REG32(PINMUX_BASE, 0x20) = 0x04000000;
	HW_REG32(PINMUX_BASE, 0x24) = 0;
	HW_REG32(PINMUX_BASE, 0x28) = 0;
	HW_REG32(PINMUX_BASE, 0x2C) = 0;
	HW_REG32(PINMUX_BASE, 0x30) = 0;
	HW_REG32(PINMUX_BASE, 0x34) = 0;
	HW_REG32(PINMUX_BASE, 0x38) = 0;
#else
	HW_REG32(PINMUX_BASE, 0x10) = 0;
	HW_REG32(PINMUX_BASE, 0x14) = 0;
	HW_REG32(PINMUX_BASE, 0x18) = 0;
	HW_REG32(PINMUX_BASE, 0x1C) = 0x11110011;	/* PINMUX for JTAG and SE-UART */
	HW_REG32(PINMUX_BASE, 0x20) = 0;
	HW_REG32(PINMUX_BASE, 0x24) = 0;
	HW_REG32(PINMUX_BASE, 0x28) = 0;
	HW_REG32(PINMUX_BASE, 0x2C) = 0;
	HW_REG32(PINMUX_BASE, 0x30) = 0;
	HW_REG32(PINMUX_BASE, 0x34) = 0;
	HW_REG32(PINMUX_BASE, 0x38) = 0;
#endif

	BOARD_BUTTON1_GPIOdrv->SetDirection(BOARD_BUTTON1_PIN_NO, GPIO_PIN_DIRECTION_INPUT);
	PINMUX_Config(BOARD_BUTTON1_GPIO_PORT-1, BOARD_BUTTON1_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_BUTTON2_GPIOdrv->SetDirection(BOARD_BUTTON2_PIN_NO, GPIO_PIN_DIRECTION_INPUT);
	PINMUX_Config(BOARD_BUTTON2_GPIO_PORT-1, BOARD_BUTTON2_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_LED1_GPIOdrv->SetValue(BOARD_LED1_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_LED1_GPIOdrv->SetDirection(BOARD_LED1_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_LED1_GPIO_PORT-1, BOARD_LED1_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_LED2_GPIOdrv->SetValue(BOARD_LED2_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_LED2_GPIOdrv->SetDirection(BOARD_LED2_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_LED2_GPIO_PORT-1, BOARD_LED2_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_LCD_RESET_GPIOdrv->SetValue(BOARD_LCD_RESET_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_LCD_RESET_GPIOdrv->SetDirection(BOARD_LCD_RESET_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_LCD_RESET_GPIO_PORT-1, BOARD_LCD_RESET_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_LCD_BACKLIGHT_GPIOdrv->SetValue(BOARD_LCD_BACKLIGHT_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_LCD_BACKLIGHT_GPIOdrv->SetDirection(BOARD_LCD_BACKLIGHT_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_LCD_BACKLIGHT_GPIO_PORT-1, BOARD_LCD_BACKLIGHT_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_TOUCH_RESET_GPIOdrv->SetValue(BOARD_TOUCH_RESET_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_TOUCH_RESET_GPIOdrv->SetDirection(BOARD_TOUCH_RESET_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_TOUCH_RESET_GPIO_PORT-1, BOARD_TOUCH_RESET_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_TOUCH_INT_GPIOdrv->SetValue(BOARD_TOUCH_INT_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_TOUCH_INT_GPIOdrv->SetDirection(BOARD_TOUCH_INT_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_TOUCH_INT_GPIO_PORT-1, BOARD_TOUCH_INT_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	BOARD_CAMERA_RESET_GPIOdrv->SetValue(BOARD_CAMERA_RESET_PIN_NO, GPIO_PIN_OUTPUT_STATE_LOW);
	BOARD_CAMERA_RESET_GPIOdrv->SetDirection(BOARD_CAMERA_RESET_PIN_NO, GPIO_PIN_DIRECTION_OUTPUT);
	PINMUX_Config(BOARD_CAMERA_RESET_GPIO_PORT-1, BOARD_CAMERA_RESET_PIN_NO, PINMUX_ALTERNATE_FUNCTION_0);

	/* OSPI0 interface */
	PINMUX_Config(PORT_NUMBER_1, PIN_NUMBER_16, PINMUX_ALTERNATE_FUNCTION_3); // D0
	PINMUX_Config(PORT_NUMBER_1, PIN_NUMBER_17, PINMUX_ALTERNATE_FUNCTION_3); // D1
	PINMUX_Config(PORT_NUMBER_1, PIN_NUMBER_18, PINMUX_ALTERNATE_FUNCTION_3); // D2
	PINMUX_Config(PORT_NUMBER_1, PIN_NUMBER_19, PINMUX_ALTERNATE_FUNCTION_3); // D3
	PINMUX_Config(PORT_NUMBER_1, PIN_NUMBER_20, PINMUX_ALTERNATE_FUNCTION_3); // D4
	PINMUX_Config(PORT_NUMBER_1, PIN_NUMBER_21, PINMUX_ALTERNATE_FUNCTION_4); // D5
	PINMUX_Config(PORT_NUMBER_1, PIN_NUMBER_22, PINMUX_ALTERNATE_FUNCTION_4); // D6
	PINMUX_Config(PORT_NUMBER_1, PIN_NUMBER_23, PINMUX_ALTERNATE_FUNCTION_3); // D7
	PINMUX_Config(PORT_NUMBER_1, PIN_NUMBER_25, PINMUX_ALTERNATE_FUNCTION_3); // SCLK
	PINMUX_Config(PORT_NUMBER_1, PIN_NUMBER_26, PINMUX_ALTERNATE_FUNCTION_3); // RXDS
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_6, PINMUX_ALTERNATE_FUNCTION_4);  // CS
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_0, PINMUX_ALTERNATE_FUNCTION_0);  // RESET
	PINPAD_Config(PORT_NUMBER_1, PIN_NUMBER_16, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_1, PIN_NUMBER_17, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_1, PIN_NUMBER_18, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_1, PIN_NUMBER_19, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_1, PIN_NUMBER_20, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_1, PIN_NUMBER_21, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_1, PIN_NUMBER_22, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_1, PIN_NUMBER_23, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_1, PIN_NUMBER_25, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_1, PIN_NUMBER_26, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_2, PIN_NUMBER_6, PAD_FUNCTION_READ_ENABLE);
	PINPAD_Config(PORT_NUMBER_3, PIN_NUMBER_0, PAD_FUNCTION_READ_ENABLE);

	/* I2S2 interface */
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_1, PINMUX_ALTERNATE_FUNCTION_3);    // P2_1: SDI (mux mode 3)
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_3, PINMUX_ALTERNATE_FUNCTION_3);    // P2_3: SCLK(mux mode 3)
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_4, PINMUX_ALTERNATE_FUNCTION_2);    // P2_4: WS  (mux mode 2)

	/* CAMERA clock output */
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_7, PINMUX_ALTERNATE_FUNCTION_6);

	/* SPI3 interface */
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_21, PINMUX_ALTERNATE_FUNCTION_4);   // P2_21: MISO (mux mode 4)
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_22, PINMUX_ALTERNATE_FUNCTION_3);   // P2_22: MOSI (mux mode 3)
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_23, PINMUX_ALTERNATE_FUNCTION_3);   // P2_23: SCLK (mux mode 4)
	PINMUX_Config(PORT_NUMBER_2, PIN_NUMBER_24, PINMUX_ALTERNATE_FUNCTION_0);   // P2_24: GPIO (mux mode 0)

	/* UART4 interface */
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_1, PINMUX_ALTERNATE_FUNCTION_1);	// P3_1: RX  (mux mode 1)
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_2, PINMUX_ALTERNATE_FUNCTION_1);	// P3_2: TX  (mux mode 1)

	/* I3C interface */
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_8, PINMUX_ALTERNATE_FUNCTION_3);    // P3_8: SDA (mux mode 3)
	PINPAD_Config(PORT_NUMBER_3, PIN_NUMBER_8, config_i3c);
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_9, PINMUX_ALTERNATE_FUNCTION_4);    // P3_9: SCL (mux mode 4)
	PINPAD_Config(PORT_NUMBER_3, PIN_NUMBER_9, config_i3c);

	/* Board Pin mux Configurations */
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_10, PINMUX_ALTERNATE_FUNCTION_3); //CMD
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_11, PINMUX_ALTERNATE_FUNCTION_3); //CLK
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_12, PINMUX_ALTERNATE_FUNCTION_4); //D0
#ifdef SD_4BIT_MODE
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_13, PINMUX_ALTERNATE_FUNCTION_4); //D1
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_14, PINMUX_ALTERNATE_FUNCTION_3); //D2
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_15, PINMUX_ALTERNATE_FUNCTION_4); //D3
#endif

	/* UART6 interface */
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_14, PINMUX_ALTERNATE_FUNCTION_1);	// P3_14:RX  (mux mode 1)
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_15, PINMUX_ALTERNATE_FUNCTION_2);	// P3_15:TX  (mux mode 2)

	/* UART2 interface */
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_16, PINMUX_ALTERNATE_FUNCTION_2);	// P3_16:RX  (mux mode 2)
	PINMUX_Config(PORT_NUMBER_3, PIN_NUMBER_17, PINMUX_ALTERNATE_FUNCTION_2);	// P3_17:TX  (mux mode 2)
}

void BOARD_Clock_Init()
{
	/* Configure any SoC clock muxes and dividers
	 * if not already covered in driver code
	 */
}

void BOARD_Power_Init()
{
	/* Configure any board level power supplies
	 * or release reset to board mounted ICs
	 */
}

void BOARD_BUTTON1_Init(BOARD_Callback_t user_cb)
{
	ARM_DRIVER_GPIO *BOARD_BUTTON1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON1_GPIO_PORT);
	BOARD_BUTTON1_GPIOdrv->Initialize(BOARD_BUTTON1_PIN_NO, user_cb);
}

void BOARD_BUTTON2_Init(BOARD_Callback_t user_cb)
{
	ARM_DRIVER_GPIO *BOARD_BUTTON2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON2_GPIO_PORT);
	BOARD_BUTTON2_GPIOdrv->Initialize(BOARD_BUTTON2_PIN_NO, user_cb);
}

void BOARD_BUTTON1_Control(BOARD_BUTTON_CONTROL control)
{
	uint32_t arg = ARM_GPIO_IRQ_POLARITY_LOW | ARM_GPIO_IRQ_SENSITIVE_EDGE;

	ARM_DRIVER_GPIO *BOARD_BUTTON1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON1_GPIO_PORT);
	BOARD_BUTTON1_GPIOdrv->Control(BOARD_BUTTON1_PIN_NO, (GPIO_OPERATION) control, &arg);
}

void BOARD_BUTTON2_Control(BOARD_BUTTON_CONTROL control)
{
	uint32_t arg = ARM_GPIO_IRQ_POLARITY_LOW | ARM_GPIO_IRQ_SENSITIVE_EDGE;

	ARM_DRIVER_GPIO *BOARD_BUTTON2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON2_GPIO_PORT);
	BOARD_BUTTON2_GPIOdrv->Control(BOARD_BUTTON2_PIN_NO, (GPIO_OPERATION) control, &arg);
}

void BOARD_BUTTON1_GetState(BOARD_BUTTON_STATE *state)
{
	ARM_DRIVER_GPIO *BOARD_BUTTON1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON1_GPIO_PORT);
	BOARD_BUTTON1_GPIOdrv->GetValue(BOARD_BUTTON1_PIN_NO, (uint32_t*)state);
}

void BOARD_BUTTON2_GetState(BOARD_BUTTON_STATE *state)
{
	ARM_DRIVER_GPIO *BOARD_BUTTON2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_BUTTON2_GPIO_PORT);
	BOARD_BUTTON2_GPIOdrv->GetValue(BOARD_BUTTON2_PIN_NO, (uint32_t*)state);
}

void BOARD_LED1_Control(BOARD_LED_STATE state)
{
	ARM_DRIVER_GPIO *BOARD_LED1_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LED1_GPIO_PORT);
	BOARD_LED1_GPIOdrv->SetValue(BOARD_LED1_PIN_NO, (GPIO_PIN_OUTPUT_STATE) state);
}

void BOARD_LED2_Control(BOARD_LED_STATE state)
{
	ARM_DRIVER_GPIO *BOARD_LED2_GPIOdrv = &ARM_Driver_GPIO_(BOARD_LED2_GPIO_PORT);
	BOARD_LED2_GPIOdrv->SetValue(BOARD_LED2_PIN_NO, (GPIO_PIN_OUTPUT_STATE) state);
}

#endif
